@@ -1,3 +1,4 @@
+
 # # #####################################################################################################################
 context("testing column existence")
 test_that("testing column existence", {
@@ -6,7 +7,7 @@ test_that("testing column existence", {
   tempdata = as.data.frame(cbind(y,x))
   colnames(tempdata)<-c("name","age")
   expect_equal(checkColumnExist("age",tempdata),0)
-
+  
 })
 context("testing column existence")
 test_that("testing column existence", {
@@ -15,16 +16,17 @@ test_that("testing column existence", {
   tempdata = as.data.frame(cbind(y,x))
   colnames(tempdata)<-c("name","num")
   expect_equal(checkColumnExist("age",tempdata),-1)
-
+  
 })
 print("----------------------------------------------")
+
 # # #####################################################################################################################
 context("testing file existence")
 test_that("test for file existence and access", {
   thisdir=getwd()
   expect_identical(testFileExistRead(thisdir),0)
   nodir="/Users/SheejaMK/Desktop/Model/filecheck/test"
-  expect_identical(testFileExistRead(nodir),-1)
+  expect_identical(testFileExistRead(nodir),-2)
 })
 print("----------------------------------------------")
 
@@ -34,30 +36,32 @@ context("testing mode function")
 test_that("testing mode function", {
   x <- c(0,11,78,160)
   expect_equal(getModeForVec(x),0)
-
+  
 })
 context("testing mode function")
 test_that("testing mode function", {
   x <- c(0,"f",78,160)
   expect_equal(getModeForVec(x),-1)
-
+  
 })
 
 context("testing mode function")
 test_that("testing mode function", {
   x <- c(78,NA,78,78)
   expect_equal(getModeForVec(x),78)
-
+  
 })
 context("testing mode function")
 test_that("testing mode function", {
   x <- c(78,"NA",78,78)
   expect_equal(getModeForVec(x),-1)
-
+  
 })
 print("----------------------------------------------")
 
 # #####################################################################################################################
+
+
 context("testing subsetGenderAgeToGroup")
 test_that("testing subsetGenderAgeToGroup", {
   set.seed(20)
@@ -74,11 +78,12 @@ test_that("testing subsetGenderAgeToGroup", {
   expect_equal(getColNumExistingColNames(c("sex","gender","male","female","f","m"),sampledata),2)
   expect_equal(getColNumExistingColNames(c("gender","male","female","f","m"),sampledata),-1)
   expect_equal(getColNumExistingColNames("",sampledata),-1)
-
+  
 })
 print("----------------------------------------------")
 
 # # #####################################################################################################################
+
 context("testing subsetGenderAgeToGroup")
 test_that("testing subsetGenderAgeToGroup", {
   set.seed(17)
@@ -96,19 +101,17 @@ test_that("testing subsetGenderAgeToGroup", {
   one<-subset(sampledata,sex=="M")
   two<-subset(one,one$age>=10 & one$age<= 70)
   expect_equal(subsetGenderAgeToGroup(sampledata,"male",c(10,70)),two)
-
   one<-subset(sampledata,sex=="F")
   two<-subset(one,one$age>=0 & one$age<= 10)
   expect_equal(subsetGenderAgeToGroup(sampledata,"female",c(0,10)),two)
-  expect_identical(subsetGenderAgeToGroup(sampledata,"bh",c(10,70)),-1)
-  expect_identical(subsetGenderAgeToGroup(sampledata,"bh",NULL),-1)
-
+  expect_identical(subsetGenderAgeToGroup(sampledata,"bh",c(10,70)),-2)
+  expect_identical(subsetGenderAgeToGroup(sampledata,"bh",NULL),-2)
   one<-subset(sampledata,sex=="M")
   expect_identical(subsetGenderAgeToGroup(sampledata,"male",NULL),one)
-
 })
 print("----------------------------------------------")
 
+
 # # #####################################################################################################################
 
 context("testing descritpvie statistics")
@@ -118,7 +121,7 @@ test_that("testing descritpvie statistics", {
   colnames(results)<-c("Sum","Mean","SD","Median", "Mode","SE","Minimum","Maximum","Count")
   rownames(results)<-"age"
   expect_equal(descriptiveStatDataColumn(x,"age",NA),results,tolerance=0.001)
-
+  
 })
 
 context("testing descriptive statistics")
@@ -128,9 +131,10 @@ test_that("testing descriptive statistics", {
   colnames(results)<-c("Sum","Mean","SD","Median", "Mode","SE","Minimum","Maximum","Count")
   rownames(results)<-"age"
   expect_equal(descriptiveStatDataColumn(x,"age",0),results,tolerance=0.001)
-
+  
 })
 
+
 context("testing descriptive statistics")
 test_that("testing descriptive statistics", {
   x <- c(0,NA,78,160)
@@ -138,25 +142,23 @@ test_that("testing descriptive statistics", {
   colnames(results)<-c("Sum","Mean","SD","Median", "Mode","SE","Minimum","Maximum","Count")
   rownames(results)<-"age"
   expect_equal(descriptiveStatDataColumn(x,"age",NA),results,tolerance=0.001)
-
+  
 })
 
 context("testing descriptive statistics")
 test_that("testing descriptive statistics", {
   x <- c(0,NA,"dd",160)
   expect_equal(descriptiveStatDataColumn(x,"age",NA),-1)
-
+  
 })
 context("testing descriptive statistics")
 test_that("testing descriptive statistics", {
   x <- c('',11,78,160)
   expect_equal(descriptiveStatDataColumn(x,"age",NA),-1)
-
+  
 })
 print("----------------------------------------------")
-
 ## # #####################################################################################################################
-
 context("testing numeric column")
 test_that("test for numeric values in a specific column but with no range given", {
   x <- c(0,11,78,120)
@@ -165,11 +167,8 @@ test_that("test for numeric values in a specific column but with no range given"
   expect_identical(testDataNumNorange(x,-99),0)
   x <- c("sheeja", 99,2,5,-99)
   expect_identical(testDataNumNorange(x,-99),-1)
-
 })
 print("----------------------------------------------")
-
-# # #####################################################################################################################
 # # #####################################################################################################################
 context("Check 3L scores")
 test_that("Checking 3L scores ", {
@@ -180,15 +179,15 @@ test_that("Checking 3L scores ", {
   the.result<-checkScores3L(11111)
   expect_identical(the.result,c(1,1,1,1,1))
   the.result<-checkScores3L(2,3,4,5,2)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-2)
   the.result<-checkScores3L(23452)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-2)
   the.result<-checkScores3L(23,-1,5,2)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-2)
   the.result<-checkScores3L("",-1,5,2)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-2)
   the.result<-checkScores3L("",-1,5,2,NA)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-2)
   the.result<-checkScores3L(11221,NA,NA)
   expect_identical(the.result,c(1,1,2,2,1))
 })
@@ -208,19 +207,19 @@ test_that("Checking 3L scores ", {
   the.result<-checkScores5L(23452)
   expect_identical(the.result,c(2,3,4,5,2))
   the.result<-checkScores5L(23458)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-2)
   the.result<-checkScores5L(23,-1,5,2)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-4)
   the.result<-checkScores5L("",-1,5,2)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-4)
   the.result<-checkScores5L("",-1,5,2,NA)
-  expect_identical(the.result,-1)
+  expect_identical(the.result,-4)
   the.result<-checkScores5L(11221,NA,NA)
   expect_identical(the.result,c(1,1,2,2,1))
 })
 print("----------------------------------------------")
-
 #####################################################################################################################
+
 context("EQ5D5L scoring ")
 test_that("EQ5D5L scoring ", {
   the.result<-valueEQ5D5LIndscores("England",1,1,1,1,2)
@@ -240,23 +239,23 @@ test_that("EQ5D5L scoring ", {
   the.result<-valueEQ5D5LIndscores("England",111)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",345678)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("NM",-11111)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-3,tolerance=1e-3)
+  
   the.result<-valueEQ5D5LIndscores("England",11112, NA, NA, NA, NA)
   expect_equal(the.result,0.922,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(1,1,1,1,2), NA, NA, NA, NA)
   expect_equal(the.result,0.922,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(1,1,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(8,1,1,2,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(1,1,1,1,2), NA, NA, NA)
   expect_equal(the.result,0.922,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",11111)
   expect_equal(the.result,1,tolerance=1e-3)
-
+  
   the.result<-valueEQ5D5LIndscores("England",c(1,1,1,1,2))
   expect_equal(the.result,0.922,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(1,1,1,2,1))
@@ -270,12 +269,12 @@ test_that("EQ5D5L scoring ", {
   the.result<-valueEQ5D5LIndscores("England",c(5,5,5,5,5))
   expect_equal(the.result,-0.285,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(3,4,5,6,7,8))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",c(-1,1,1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-2,tolerance=1e-3)
+  
   the.result<-valueEQ5D5LIndscores("England",NA,1,1,1,2)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",NA,1,1,2,1)
@@ -285,14 +284,13 @@ test_that("EQ5D5L scoring ", {
   the.result<-valueEQ5D5LIndscores("England",1,1,1,1,NA)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("England",-1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("Germany",1,1,1,1,1)
   expect_equal(the.result,1,tolerance=1e-3)
   the.result<-valueEQ5D5LIndscores("US",1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
 })
 print("----------------------------------------------")
-
 ################################################################################################################
 # #################################################################################################################
 context("testing EQ5D3L valuation using individual responses")
@@ -312,24 +310,24 @@ test_that("test for value3L", {
   the.result<-valueEQ5D3LIndscores("UK","TTO",33333)
   expect_equal(the.result,-0.594,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",55555)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",111)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",345678)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("NM","TTO",-11111)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-2,tolerance=1e-3)
+  
   the.result<-valueEQ5D3LIndscores("UK","TTO",11112, NA, NA, NA, NA)
   expect_equal(the.result,0.848,tolerance=1e-3)
-
+  
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(1,1,1,1,2), NA, NA, NA, NA)
   expect_equal(the.result,0.848,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(1,1,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(8,1,1,2,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-3,tolerance=1e-3)
+  
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(1,1,1,1,2), NA, NA, NA)
   expect_equal(the.result,0.848,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",11111)
@@ -346,13 +344,13 @@ test_that("test for value3L", {
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(2,1,1,1,1))
   expect_equal(the.result,0.85,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(5,5,5,5,5))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(3,4,5,6,7,8))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",c(-1,1,1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   #
   the.result<-valueEQ5D3LIndscores("UK","TTO",NA,1,1,1,2)
   expect_equal(the.result,NA,tolerance=1e-3)
@@ -360,23 +358,23 @@ test_that("test for value3L", {
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",NA,1,1,1)
   expect_equal(the.result,NA,tolerance=1e-3)
-
+  
   the.result<-valueEQ5D3LIndscores("UK","TTO",1,1,1,1,NA)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",-1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("DE","TTO",1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
-
+  expect_equal(the.result,-2,tolerance=1e-3)
+  
+  
   the.result<-valueEQ5D3LIndscores("UK","TTO",4,5,6,5,8)
-  expect_equal(the.result,-1)
+  expect_equal(the.result,-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",-1,2,3,2,2)
-  expect_equal(the.result,-1)
+  expect_equal(the.result,-3)
   the.result<-valueEQ5D3LIndscores("UK","TTO",123)
   expect_equal(the.result,NA)
   the.result<-valueEQ5D3LIndscores("JP","TTO",c(1,2,3,2,3))
-  expect_equal(the.result,-1)
+  expect_equal(the.result,-2)
   answers =EQ5D3L_indexvalues.df
   for (i in 1:nrow(answers)){
     the.scores3L=convertNumberToIndividualDigits(answers$state[i])
@@ -387,11 +385,11 @@ test_that("test for value3L", {
 print("----------------------------------------------")
 
 # #################################################################################################################
-#
+
 
 context("testing EQ5D3L valuation using individual responses")
 test_that("test for value3L", {
-
+  
   the.result<-valueEQ5D3LIndscores("UK","VAS",1,1,1,1,2)
   expect_equal(the.result,0.782,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",11112)
@@ -407,22 +405,22 @@ test_that("test for value3L", {
   the.result<-valueEQ5D3LIndscores("UK","VAS",33333)
   expect_equal(the.result,-0.073,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",55555)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",111)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",345678)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("NM","VAS",-11111)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-2,tolerance=1e-3)
+  
   the.result<-valueEQ5D3LIndscores("UK","VAS",11112, NA, NA, NA, NA)
   expect_equal(the.result,0.782,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(1,1,1,1,2), NA, NA, NA, NA)
   expect_equal(the.result,0.782,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(1,1,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(8,1,1,2,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(1,1,1,1,2), NA, NA, NA)
   expect_equal(the.result,0.782,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",11111)
@@ -438,13 +436,13 @@ test_that("test for value3L", {
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(2,1,1,1,1))
   expect_equal(the.result,0.774,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(5,5,5,5,5))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(3,4,5,6,7,8))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",c(-1,1,1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",NA,1,1,1,2)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",NA,1,1,2,1)
@@ -454,17 +452,17 @@ test_that("test for value3L", {
   the.result<-valueEQ5D3LIndscores("UK","VAS",1,1,1,1,NA)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",-1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("DE","VAS",1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",4,5,6,5,8)
-  expect_equal(the.result,-1)
+  expect_equal(the.result,-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",-1,2,3,2,2)
-  expect_equal(the.result,-1)
+  expect_equal(the.result,-3)
   the.result<-valueEQ5D3LIndscores("UK","VAS",123)
   expect_equal(the.result,NA)
   the.result<-valueEQ5D3LIndscores("JP","VAS",c(1,2,3,2,3))
-  expect_equal(the.result,-1)
+  expect_equal(the.result,-2)
   answers =EQ5D3L_indexvalues.df
   for (i in 1:nrow(answers)){
     the.scores3L=convertNumberToIndividualDigits(answers$state[i])
@@ -473,30 +471,31 @@ test_that("test for value3L", {
   }
 })
 print("----------------------------------------------")
-
 ###############################################################################################################
 
-context("Crosswalk EQ5D5L to 3L values for uk using van hout method")
+
+
+context("Crosswalk EQ5D5L to 3L values using Van Hout method")
 test_that("Crosswalk EQ5D5L to 3L values", {
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",56789)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",-12345)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",-1111)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","van hout",-23456)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-4,tolerance=1e-3)
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW","",12345)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,2,3,4,5))
   expect_equal(the.result,0.06333624,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",1,2,3,4,5)
   expect_equal(the.result,0.06333624,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",8,2,3,4,5)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",77777,2,3,4,5)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",NA,2,3,4,5)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",1,2,3,4,NA)
@@ -504,6 +503,7 @@ test_that("Crosswalk EQ5D5L to 3L values", {
 })
 # # #####################################################################################################################
 #
+
 context("Crosswalk EQ5D5L to 3L values for any country ")
 test_that("Crosswalk EQ5D5L to 3L values for any country ", {
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",1,1,1,1,2)
@@ -521,29 +521,29 @@ test_that("Crosswalk EQ5D5L to 3L values for any country ", {
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",55555)
   expect_equal(the.result,-0.594,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",111)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",345678)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("NM","",-11111)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-2,tolerance=1e-3)
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",11112, NA, NA, NA, NA)
   expect_equal(the.result,0.8794038,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,1,1,1,2), NA, NA, NA, NA)
   expect_equal(the.result,0.8794038,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,1,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(8,1,1,2,1), NA, NA, NA, NA)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-6,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,1,1,1,2), NA, NA, NA)
   expect_equal(the.result,0.8794038,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",11111)
   expect_equal(the.result,1,tolerance=1e-3)
-
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,1,1,1,2))
   expect_equal(the.result,0.8794038,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,1,1,2,1))
-
+  
   expect_equal(the.result,0.8365693,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,1,2,1,1))
   expect_equal(the.result,0.9061444,tolerance=1e-3)
@@ -554,12 +554,12 @@ test_that("Crosswalk EQ5D5L to 3L values for any country ", {
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(5,5,5,5,5))
   expect_equal(the.result,-0.594,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(3,4,5,6,7,8))
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-3,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(-1,1,1,1,1))
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-6,tolerance=1e-3)
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",NA,1,1,1,2)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",NA,1,1,2,1)
@@ -569,40 +569,41 @@ test_that("Crosswalk EQ5D5L to 3L values for any country ", {
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",1,1,1,1,NA)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",-1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("DE","",1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("US","",1,1,1,1,1)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-2,tolerance=1e-3)
 })
 print("----------------------------------------------")
 
 # # ########################################
+
 # #############################################################################
 context("Crosswalk EQ5D5L to 3L values for any country")
 test_that("Crosswalk EQ5D5L to 3L values", {
-
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",56789)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-4,tolerance=1e-3)
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",-12345)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",-1111)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",-23456)
-  expect_equal(the.result,-1,tolerance=1e-3)
-
+  expect_equal(the.result,-4,tolerance=1e-3)
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",12345)
   expect_equal(the.result,0.06333624,tolerance=1e-3)
-
+  
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",c(1,2,3,4,5))
   expect_equal(the.result,0.06333624,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("Japan","CW",1,2,3,4,5)
   expect_equal(the.result,0.522,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",8,2,3,4,5)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK","CW",77777,2,3,4,5)
-  expect_equal(the.result,-1,tolerance=1e-3)
+  expect_equal(the.result,-4,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK",NA,2,3,4,5)
   expect_equal(the.result,NA,tolerance=1e-3)
   the.result<-eq5dmap5Lto3LIndscores("UK",1,2,3,4,NA)
@@ -610,13 +611,15 @@ test_that("Crosswalk EQ5D5L to 3L values", {
 })
 print("----------------------------------------------")
 ################################################################################################################
+
+
 context("EQ5D5L scoring")
 test_that("EQ5D5L scoring", {
   answers =EQ5D5L_indexvalues.df
   total_entries=seq(1,nrow(answers))
   end1=length(total_entries)
   total_countries=c("Canada","China","England" ,"Germany","Hong Kong","Indonesia","Ireland",
-                     "Japan","Korea","Malaysia","Netherlands","Poland", "Portugal","Spain","Taiwan","Thailand","Uruguay")
+                    "Japan","Korea","Malaysia","Netherlands","Poland", "Portugal","Spain","Taiwan","Thailand","Uruguay")
   total<-length(total_countries)
   for(j in 1:total){
     this.country=total_countries[j]
@@ -679,6 +682,7 @@ test_that("EQ5D3L scoring", {
   }
 })
 print("----------------------------------------------")
+
 # ###############################################################################################################
 context("EQ5D5L crosswalk mapping")
 test_that("EQ5D5L crosswalk mapping", {
